# Copyright 2012, Trimble Navigation Limited

# This software is provided as an example of using the Ruby interface
# to SketchUp.

# Permission to use, copy, modify, and distribute this software for 
# any purpose and without fee is hereby granted, provided that the above
# copyright notice appear in all copies.

# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

#-----------------------------------------------------------------------------
# Name        :   Skalp for SketchUp
# Description :   A script that loads the Skalp tool as an
#                 extension to SketchUp
# Version     :   1.0.0320
# Date        :   04 November 2014
#-----------------------------------------------------------------------------

require 'sketchup.rb'
require 'SecureRandom'

unless defined?(Skalp) == 'constant'
  module Skalp
    attr_reader :skalp_extension

    SecureRandom.uuid #Workaround for very slow fist sectionplane ADD on windows
    SKALP_PATH = Sketchup.find_support_file("Plugins")+"/Skalp_Skalp/"
    SKALP_VERSION = '1.0.0320'
    SU_USER_PATH = Dir.getwd
    RUBY_PLATFORM.include?('darwin') ?  OS = :MAC : OS = :WINDOWS
    @version_required = 14

    def self.check_IE_version
      ie_dialog = UI::WebDialog.new("IE check", false, "Skalp_IE", 1, 1, 0, 0, false)
      ie_dialog.set_file(Sketchup.find_support_file("Plugins")+"/Skalp_Skalp/html/IE_check.html")
      ie_dialog.show

      ie_dialog.add_action_callback("ready"){
        ie_dialog.execute_script("check_IE_version()")
        result = ie_dialog.get_element_value('RUBY_BRIDGE')
        if result == 'false'
          @ie_check = false
        else
          @ie_check = true
        end
        ie_dialog.close
        load_extension
      }
    end

    def self.load_extension
      if @ie_check == false
        UI.messagebox('You must have Internet Explorer 10 or higher to run Skalp. Visit microsoft.com to update')
      else
        @skalp_extension = SketchupExtension.new "Skalp", "Skalp_Skalp/Skalp_loader.rb"
        @skalp_extension.version = SKALP_VERSION

        @skalp_extension.copyright = "2014, Skalp"
        @skalp_extension.creator = "Skalp"
        @skalp_extension.description = "Create Stunning Live Section Cuts. Import and tweak standard CAD Pattern files (*.pat). Use Skalp Styles to tweak Section Cut representations. Keep plans and elevations up to date in Layout. Export 2D Section Cuts to DXF. More info: www.skalp4sketchup.com"

        Sketchup.register_extension @skalp_extension, true
      end
    end

    if  (Sketchup.version.to_f < @version_required)
      UI.messagebox("You must have Sketchup 20" + @version_required.to_s +
                        " to run Skalp. Visit sketchup.com to upgrade.")
    else
      require 'fileutils'

      if File.exists?(Sketchup.find_support_file("Plugins")+"/Skalp/Skalp.lic")
         oldpath = Sketchup.find_support_file("Plugins")+"/Skalp"
         FileUtils.copy(File.join(oldpath,'Skalp.lic'), File.join(SKALP_PATH, 'Skalp.lic')) if File.exists?(File.join(oldpath,'Skalp.lic'))
      end

      FileUtils.remove_entry(Sketchup.find_support_file("Plugins")+"/Skalp.rb", true) if File.exists?(Sketchup.find_support_file("Plugins")+"/Skalp.rb")

      require 'extensions.rb'
      require 'LangHandler.rb'

      @ie_check = true

      if OS == :WINDOWS
        check_IE_version
      else
        load_extension
      end
    end
  end
end


